/*
 * This file is part of broccoli.
 * Copyright (C) 2019 Chair of Applied Mechanics, Technical University of Munich
 * https://www.amm.mw.tum.de/
 */

#pragma once // Load this file only once

#include "core/FixedStepArithmeticNumber.hpp"
#include "core/IntegerTimeTypes.hpp"
#include "core/Time.hpp"
#include "core/floats.hpp"
#include "core/math.hpp"

/** \defgroup broccoli_core_module broccoli Core Module
  * The *core* module provides core functionalities like extensions to the
  * standard or Eigen's math library and helpers for high precision timing.
  * Include all functionalities of this module with
  * \code
  * #include <broccoli/core.hpp>
  * \endcode
  *
  * In order to keep compilation time low it is suggested that you include only the files you really need:
  *
  * File | Description
  * ---- | -----------
  * \code #include "core/floats.hpp" \endcode | Defines \ref broccoli::core::floats - \copybrief broccoli::core::floats
  * \code #include "core/math.hpp" \endcode | Defines \ref broccoli::core::math - \copybrief broccoli::core::math
  * \code #include "core/Time.hpp" \endcode | Defines \ref broccoli::core::Time - \copybrief broccoli::core::Time
  * \code #include "core/FixedStepArithmeticNumber.hpp" \endcode | Defines \ref broccoli::core::FixedStepArithmeticNumber - \copybrief broccoli::core::FixedStepArithmeticNumber
  * \code #include "core/IntegerTimeTypes.hpp" \endcode | \copybrief IntegerTimeTypes.hpp
  */

// Documentation of namespace
namespace broccoli {
//! Namespace of \ref broccoli_core_module
namespace core {
}
}
