/*
 * This file is part of broccoli.
 * Copyright (C) 2019 Chair of Applied Mechanics, Technical University of Munich
 * https://www.amm.mw.tum.de/
 */

#pragma once // Load this file only once

#include "curve/Curve.hpp"
#include "curve/Exponential.hpp"
#include "curve/Polynomial.hpp"
#include "curve/QuaternionCurve.hpp"
#include "curve/QuaternionSLERPCurve.hpp"
#include "curve/QuaternionSpline.hpp"
#include "curve/QuaternionTrajectory.hpp"
#include "curve/Spline.hpp"
#include "curve/Trajectory.hpp"
#include "curve/Trigonometric.hpp"

/*! \defgroup broccoli_curve_module broccoli Curve Module
  * The *curve* module provides classes for creating, interpolating and evaluating curves, splines and trajectories.
  * Aside from multi-dimensional trajectories also special quaternion trajectories for animating rotations
  * are included.
  * Include all functionalities of this module with
  * \code
  * #include <broccoli/curve.hpp>
  * \endcode
  *
  * In order to keep compilation time low it is suggested that you include only the files you really need:
  *
  * File | Description
  * ---- | -----------
  * \code #include "curve/Curve.hpp" \endcode | Defines \ref broccoli::curve::Curve - \copybrief broccoli::curve::Curve
  * \code #include "curve/QuaternionCurve.hpp" \endcode | Defines \ref broccoli::curve::QuaternionCurve - \copybrief broccoli::curve::QuaternionCurve
  * \code #include "curve/Polynomial.hpp" \endcode | Defines \ref broccoli::curve::Polynomial - \copybrief broccoli::curve::Polynomial
  * \code #include "curve/Exponential.hpp" \endcode | Defines \ref broccoli::curve::Exponential - \copybrief broccoli::curve::Exponential
  * \code #include "curve/Trigonometric.hpp" \endcode | Defines \ref broccoli::curve::Trigonometric - \copybrief broccoli::curve::Trigonometric
  * \code #include "curve/QuaternionSLERPCurve.hpp" \endcode | Defines \ref broccoli::curve::QuaternionSLERPCurve - \copybrief broccoli::curve::QuaternionSLERPCurve
  * \code #include "curve/Spline.hpp" \endcode | Defines \ref broccoli::curve::Spline - \copybrief broccoli::curve::Spline
  * \code #include "curve/QuaternionSpline.hpp" \endcode | Defines \ref broccoli::curve::QuaternionSpline - \copybrief broccoli::curve::QuaternionSpline
  * \code #include "curve/Trajectory.hpp" \endcode | Defines \ref broccoli::curve::Trajectory - \copybrief broccoli::curve::Trajectory
  * \code #include "curve/QuaternionTrajectory.hpp" \endcode | Defines \ref broccoli::curve::QuaternionTrajectory - \copybrief broccoli::curve::QuaternionTrajectory
  */

// Documentation of namespace
namespace broccoli {
//! Namespace of \ref broccoli_curve_module
namespace curve {
}
}
