/*
 * This file is part of broccoli.
 * Copyright (C) 2019 Chair of Applied Mechanics, Technical University of Munich
 * https://www.amm.mw.tum.de/
 */

#pragma once // Load this file only once

#include "LogFileData.hpp"
#include "encoding.hpp"

namespace broccoli {
namespace io {
    //! Simple string container for log data
    /*!
     * Spezialization of generic \ref LogFileData for simple data to log (which can be represented as string).
     */
    class LogFileDataString : public LogFileData {
    public:
        //! Default constructor
        /*!
         * \param [in] data Sets \ref m_data - \copybrief m_data
         */
        LogFileDataString(const std::string& data = "")
            : m_data(data)
        {
        }

        //! Destructor
        virtual ~LogFileDataString()
        {
        }

        // Members
        std::string m_data; //!< Contains the string to write

        // Encodes member data to logging stream (see base class for details)
        virtual LogStreamSize encodeDataToLogStream(LogStream& stream) const
        {
            // Simple string encoding
            return encoding::encode(stream, m_data);
        }
    };
} // namespace io
} // namespace broccoli
