/*
 * This file is part of broccoli.
 * Copyright (C) 2019 Chair of Applied Mechanics, Technical University of Munich
 * https://www.amm.mw.tum.de/
 */

#pragma once // Load this file only once

#include "ode/AbstractSolvable.hpp"
#include "ode/AbstractSolvableEntity.hpp"
#include "ode/AbstractSolvableListener.hpp"
#include "ode/CubicSplineCollocator.hpp"
#include "ode/QuinticSplineCollocator.hpp"
#include "ode/SequentiallySolvableSystem.hpp"
#include "ode/SplineCollocatorBase.hpp"
#include "ode/solvers/AbstractFixedStepSystemSolver.hpp"
#include "ode/solvers/AbstractSystemSolver.hpp"
#include "ode/solvers/ForwardEulerSystemSolver.hpp"

/*! \defgroup broccoli_ode_module broccoli ODE Module
  * The *ODE* module provides a collection of algorithms related to ordinary differential equations (ODEs).
  * Include all functionalities of this module with
  * \code
  * #include <broccoli/ode.hpp>
  * \endcode
  *
  * In order to keep compilation time low it is suggested that you include only the files you really need:
  *
  * Spline Collocation
  * ------------------
  * File | Description
  * ---- | -----------
  * \code #include "ode/SplineCollocatorBase.hpp" \endcode | Defines \ref broccoli::ode::SplineCollocatorBase - \copybrief broccoli::ode::SplineCollocatorBase
  * \code #include "ode/CubicSplineCollocator.hpp" \endcode | Defines \ref broccoli::ode::CubicSplineCollocator - \copybrief broccoli::ode::CubicSplineCollocator
  * \code #include "ode/QuinticSplineCollocator.hpp" \endcode | Defines \ref broccoli::ode::QuinticSplineCollocator - \copybrief broccoli::ode::QuinticSplineCollocator
  *
  * Time Integration of ODEs
  * ------------------
  * File | Description
  * ---- | -----------
  * \code #include "ode/AbstractSolvableListener.hpp" \endcode | Defines \ref broccoli::ode::AbstractSolvableListener - \copybrief broccoli::ode::AbstractSolvableListener
  * \code #include "ode/AbstractSolvable.hpp" \endcode | Defines \ref broccoli::ode::AbstractSolvable - \copybrief broccoli::ode::AbstractSolvable
  * \code #include "ode/AbstractSolvableEntity.hpp" \endcode | Defines \ref broccoli::ode::AbstractSolvableEntity - \copybrief broccoli::ode::AbstractSolvableEntity
  * \code #include "ode/AbstractTimeDiscreteSolvableEntity.hpp" \endcode | Defines \ref broccoli::ode::AbstractTimeDiscreteSolvableEntity - \copybrief broccoli::ode::AbstractTimeDiscreteSolvableEntity
  * \code #include "ode/SequentiallySolvableSystem.hpp" \endcode | Defines \ref broccoli::ode::SequentiallySolvableSystem - \copybrief broccoli::ode::SequentiallySolvableSystem
  * \code #include "ode/solvers/AbstractSystemSolver.hpp" \endcode | Defines \ref broccoli::ode::AbstractSystemSolver - \copybrief broccoli::ode::AbstractSystemSolver
  * \code #include "ode/solvers/AbstractFixedStepSystemSolver.hpp" \endcode | Defines \ref broccoli::ode::AbstractFixedStepSystemSolver - \copybrief broccoli::ode::AbstractFixedStepSystemSolver
  * \code #include "ode/solvers/ForwardEulerSystemSolver.hpp" \endcode | Defines \ref broccoli::ode::ForwardEulerSystemSolver - \copybrief broccoli::ode::ForwardEulerSystemSolver
  */

// Documentation of namespace
namespace broccoli {
//! Namespace of \ref broccoli_ode_module
namespace ode {
}
}
