/*
 * This file is part of broccoli.
 * Copyright (C) 2019 Chair of Applied Mechanics, Technical University of Munich
 * https://www.amm.mw.tum.de/
 */

#include "broccoli/core/floats.hpp"
#include "gtest/gtest.h"

using namespace broccoli::core::floats;

//! Test isEqual()
TEST(floats, isEqual)
{
    EXPECT_FALSE(isEqual(0.0000000000000022204460492503131, 0.0, 4, 2));
    EXPECT_TRUE(isEqual(std::numeric_limits<double>::epsilon(), 0.0, 4, 2));

    IntegerUnionMatchingType<double> doubleUnion(32343323.02);
    doubleUnion.asInteger += 4;

    EXPECT_FALSE(isEqual(doubleUnion.value, 32343323.02, 0, 2));    // Just using epsilon
    EXPECT_TRUE(isEqual(doubleUnion.value, 32343323.02, 4, 2));     // BUT: Epsilon is NOT enough for big numbers!

    EXPECT_FALSE(isEqual(doubleUnion.value, -32343323.02));
    EXPECT_FALSE(isEqual(nan(""), 1.0));
}

//! Test isLess(), isEqualOrLess(), isGreater(), isEqualOrGreater()
TEST(floats, notEqual)
{
    EXPECT_FALSE(isLess(nan(""), 1.0));
    EXPECT_FALSE(isLessOrEqual(nan(""), 1.0));

    EXPECT_TRUE(isLess(1.0, 2.0));
    EXPECT_FALSE(isLess(1.0, 1.0));

    EXPECT_TRUE(isLessOrEqual(1.0, 2.0));
    EXPECT_TRUE(isLessOrEqual(1.0, 1.0));

    EXPECT_FALSE(isGreater(nan(""), 1.0));
    EXPECT_FALSE(isGreaterOrEqual(nan(""), 1.0));

    EXPECT_TRUE(isGreater(2.0, 1.0));
    EXPECT_FALSE(isGreater(1.0, 1.0));

    EXPECT_TRUE(isGreaterOrEqual(2.0, 1.0));
    EXPECT_TRUE(isGreaterOrEqual(1.0, 1.0));
}